@@ -33,16 +33,48 @@
 
 #include "tclInt.h"
 
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+#ifdef HAVE_STRING_H
+#  include <string.h>
+#endif
+#ifdef HAVE_STRINGS_H
+#  include <strings.h>
+#endif
+
+/* For dladdr() and Dl_info */
+#ifdef HAVE_DLFCN_H
+#  include <dlfcn.h>
+#endif
+
+#if defined(HAVE_TCL_GETENCODINGNAMEFROMENVIRONMENT) && defined(HAVE_TCL_SETSYSTEMENCODING)
+#  define TCLKIT_CAN_SET_ENCODING 1
+#endif
+#if 10 * TCL_MAJOR_VERSION + TCL_MINOR_VERSION < 85
+#  define TCLKIT_REQUIRE_TCLEXECUTABLENAME 1
+#endif
+
+#if 10 * TCL_MAJOR_VERSION + TCL_MINOR_VERSION < 85
+#  define KIT_INCLUDES_PWB 1
+#endif
+#if 10 * TCL_MAJOR_VERSION + TCL_MINOR_VERSION < 86
+#  define KIT_INCLUDES_ZLIB 1
+#endif
+
 #ifdef KIT_INCLUDES_ITCL
 Tcl_AppInitProc	Itcl_Init;
 #endif
 #ifdef KIT_INCLUDES_MK4TCL
 Tcl_AppInitProc	Mk4tcl_Init;
 #endif
-Tcl_AppInitProc Vfs_Init, Rechan_Init, Zlib_Init;
-#if 10 * TCL_MAJOR_VERSION + TCL_MINOR_VERSION < 85
+Tcl_AppInitProc Vfs_Init, Rechan_Init;
+#ifdef KIT_INCLUDES_PWB
 Tcl_AppInitProc	Pwb_Init;
 #endif
+#ifdef KIT_INCLUDES_ZLIB
+Tcl_AppInitProc Zlib_Init;
+#endif
 #ifdef TCL_THREADS
 Tcl_AppInitProc	Thread_Init;
 #endif
@@ -62,7 +94,9 @@ Tcl_AppInitProc	Dde_Init, Registry_Init;
 #  endif
 #endif
 
+#ifdef TCLKIT_REQUIRE_TCLEXECUTABLENAME
 char *tclExecutableName;
+#endif
 
     /*
      *  Attempt to load a "boot.tcl" entry from the embedded MetaKit file.
@@ -109,12 +143,21 @@ static char *preInitCmd =
 #ifdef KIT_STORAGE_ZIP
 	"set ::tclKitStorage \"zip\"\n"
 	"catch { load {} vfs }\n"
-#  include "zipvfs.tcl.h"
-	"catch {\n"
-		"set ::tclKitStorage_fd [zip::open [info nameofexecutable]]\n"
-	"}\n"
-	"if {![catch { ::zip::stat $::tclKitStorage_fd boot.tcl sb }]} {\n"
+	"if {![info exists s]} {\n"
 		"catch {\n"
+			"set bootfile [file join [info nameofexecutable] boot.tcl]\n"
+			"if {[file exists $bootfile]} {\n"
+				"set f [open $bootfile]\n"
+				"set s [read $f]\n"
+				"close $f\n"
+			"}\n"
+		"}\n"
+	"}\n"
+	"if {![info exists s]} {\n"
+#  include "zipvfs.tcl.h"
+		"catch {\n"
+			"set ::tclKitStorage_fd [::zip::open [info nameofexecutable]]\n"
+			"::zip::stat $::tclKitStorage_fd boot.tcl sb\n"
 			"seek $::tclKitStorage_fd $sb(ino)\n"
 			"zip::Data $::tclKitStorage_fd sb s\n"
 		"}\n"
@@ -126,6 +169,13 @@ static char *preInitCmd =
 		"close $f\n"
 	"}\n"
 	"uplevel #0 $s\n"
+#if defined(KIT_INCLUDES_TK) && defined(KIT_TK_VERSION)
+#  ifndef _WIN32
+	"package ifneeded Tk " KIT_TK_VERSION " {\n"
+		"load {} Tk\n"
+	"}\n"
+#  endif
+#endif
 #ifdef _WIN32
 	"catch {load {} dde}\n"
 	"catch {load {} registry}\n"
@@ -147,32 +197,103 @@ static const char initScript[] =
 
    Hack to get around Tcl bug 1224888.
 */
-void SetExecName(Tcl_Interp *interp) {
-	if (tclExecutableName == NULL) {
-		int len = 0;
-		Tcl_Obj *execNameObj;
-		Tcl_Obj *lobjv[1];
+static void SetExecName(Tcl_Interp *interp, const char *path) {
+#ifdef TCLKIT_REQUIRE_TCLEXECUTABLENAME
+	tclExecutableName = strdup(path);
+#endif
+	Tcl_FindExecutable(path);
 
+	return;
+}
+
+static void FindAndSetExecName(Tcl_Interp *interp) {
+	int len = 0;
+	Tcl_Obj *execNameObj;
+	Tcl_Obj *lobjv[1];
+#ifdef HAVE_READLINK
+	ssize_t readlink_ret;
+	char exe_buf[4096];
+#endif /* HAVE_READLINK */
+#ifdef HAVE_ACCEPTABLE_DLADDR
+	Dl_info syminfo;
+	int dladdr_ret;
+#endif /* HAVE_ACCEPTABLE_DLADDR */ 
+
+#ifdef HAVE_READLINK
+	if (Tcl_GetNameOfExecutable() == NULL) {
+		readlink_ret = readlink("/proc/self/exe", exe_buf, sizeof(exe_buf) - 1);
+
+		if (readlink_ret > 0 && readlink_ret < (sizeof(exe_buf) - 1)) {
+			exe_buf[readlink_ret] = '\0';
+
+			SetExecName(interp, exe_buf);
+
+			return;
+		}
+	}
+
+	if (Tcl_GetNameOfExecutable() == NULL) {
+		readlink_ret = readlink("/proc/curproc/file", exe_buf, sizeof(exe_buf) - 1);
+
+		if (readlink_ret > 0 && readlink_ret < (sizeof(exe_buf) - 1)) {
+			exe_buf[readlink_ret] = '\0';
+
+			if (strcmp(exe_buf, "unknown") != 0) {
+				SetExecName(interp, exe_buf);
+
+				return;
+			}
+		}
+	}
+#endif /* HAVE_READLINK */
+
+#ifdef HAVE_ACCEPTABLE_DLADDR
+	if (Tcl_GetNameOfExecutable() == NULL) {
+		dladdr_ret = dladdr(&SetExecName, &syminfo);
+		if (dladdr_ret != 0) {
+			SetExecName(interp, syminfo.dli_fname);
+		}
+	}
+#endif /* HAVE_ACCEPTABLE_DLADDR */
+
+	if (Tcl_GetNameOfExecutable() == NULL) {
 		lobjv[0] = Tcl_GetVar2Ex(interp, "argv0", NULL, TCL_GLOBAL_ONLY);
 		execNameObj = Tcl_FSJoinToPath(Tcl_FSGetCwd(interp), 1, lobjv);
 
-		tclExecutableName = strdup(Tcl_GetStringFromObj(execNameObj, &len));
+		SetExecName(interp, Tcl_GetStringFromObj(execNameObj, &len));
+
+		return;
 	}
+
+	return;
 }
 
 int TclKit_AppInit(Tcl_Interp *interp) {
+#ifdef KIT_INCLUDES_TK
+#  ifdef _WIN32
+#    ifndef _WIN32_WCE
+	char msgBuf[2049];
+#    endif /* !_WIN32_WCE */
+#  endif /* _WIN32 */
+#endif /* KIT_INCLUDES_TK */
+#ifdef TCLKIT_CAN_SET_ENCODING
+	Tcl_DString encodingName;
+#endif /* TCLKIT_CAN_SET_ENCODING */
+
 #ifdef KIT_INCLUDES_ITCL
 	Tcl_StaticPackage(0, "Itcl", Itcl_Init, NULL);
 #endif 
 #ifdef KIT_INCLUDES_MK4TCL
 	Tcl_StaticPackage(0, "Mk4tcl", Mk4tcl_Init, NULL);
 #endif
-#if 10 * TCL_MAJOR_VERSION + TCL_MINOR_VERSION < 85
+#ifdef KIT_INCLUDES_PWB
 	Tcl_StaticPackage(0, "pwb", Pwb_Init, NULL);
 #endif 
 	Tcl_StaticPackage(0, "rechan", Rechan_Init, NULL);
 	Tcl_StaticPackage(0, "vfs", Vfs_Init, NULL);
+#ifdef KIT_INCLUDES_ZLIB
 	Tcl_StaticPackage(0, "zlib", Zlib_Init, NULL);
+#endif
 #ifdef TCL_THREADS
 	Tcl_StaticPackage(0, "Thread", Thread_Init, NULL);
 #endif
@@ -191,10 +312,18 @@ int TclKit_AppInit(Tcl_Interp *interp) {
 	Tcl_SetVar(interp, "tcl_rcFileName", "~/.tclkitrc", TCL_GLOBAL_ONLY);
 #endif
 
+#ifdef TCLKIT_CAN_SET_ENCODING
+	/* Set the encoding from the Environment */
+	Tcl_GetEncodingNameFromEnvironment(&encodingName);
+	Tcl_SetSystemEncoding(NULL, Tcl_DStringValue(&encodingName));
+	Tcl_SetVar(interp, "tclkit_system_encoding", Tcl_DStringValue(&encodingName), 0);
+	Tcl_DStringFree(&encodingName);
+#endif
+
 	/* Hack to get around Tcl bug 1224888.  This must be run here and
 	 * in LibraryPathObjCmd because this information is needed both
 	 * before and after that command is run. */
-	SetExecName(interp);
+	FindAndSetExecName(interp);
 
 	TclSetPreInitScript(preInitCmd);
 	if (Tcl_Init(interp) == TCL_ERROR) {
@@ -237,8 +366,13 @@ error:
 #  ifdef _WIN32
 	MessageBeep(MB_ICONEXCLAMATION);
 #    ifndef _WIN32_WCE
-	MessageBox(NULL, Tcl_GetStringResult(interp), "Error in TclKit",
-	           MB_ICONSTOP | MB_OK | MB_TASKMODAL | MB_SETFOREGROUND);
+	snprintf(msgBuf, sizeof(msgBuf),
+		"A critical error has occurred.  Please report this to the Tclkit vendor.\nInterpreter Returned: %s\nError Info: %s",
+		Tcl_GetStringResult(interp),
+		Tcl_GetVar(interp, "errorInfo", TCL_GLOBAL_ONLY));
+
+	MessageBox(NULL, msgBuf, "Error in TclKit",
+		MB_ICONSTOP | MB_OK | MB_TASKMODAL | MB_SETFOREGROUND);
 
 	ExitProcess(1);
 #    endif /* !_WIN32_WCE */
