@@ -106,6 +106,10 @@
 	"	    \n"
 	"	    ::zip::stat $zipfd $name sb\n"
 	"\n"
+	"            if {$sb(ino) == -1} {\n"
+	"                vfs::filesystem posixerror $::vfs::posix(EISDIR)\n"
+	"            }\n"
+	"\n"
 	"	    set nfd [vfs::memchan]\n"
 	"	    fconfigure $nfd -translation binary\n"
 	"\n"
@@ -239,44 +243,6 @@
 	"    # The pre-VFS environment will not have access to \"clock\", so don't even\n"
 	"    # bother\n"
 	"    return 0\n"
-	"\n"
-	"    set time [u_short $time]\n"
-	"    set date [u_short $date]\n"
-	"\n"
-	"    # time = fedcba9876543210\n"
-	"    #        HHHHHmmmmmmSSSSS (sec/2 actually)\n"
-	"\n"
-	"    # data = fedcba9876543210\n"
-	"    #        yyyyyyyMMMMddddd\n"
-	"\n"
-	"    set sec  [expr { ($time & 0x1F) * 2 }]\n"
-	"    set min  [expr { ($time >> 5) & 0x3F }]\n"
-	"    set hour [expr { ($time >> 11) & 0x1F }]\n"
-	"\n"
-	"    set mday [expr { $date & 0x1F }]\n"
-	"    set mon  [expr { (($date >> 5) & 0xF) }]\n"
-	"    set year [expr { (($date >> 9) & 0xFF) + 1980 }]\n"
-	"\n"
-	"    # Fix up bad date/time data, no need to fail\n"
-	"    if {$sec  > 59} {set sec  59}\n"
-	"    if {$min  > 59} {set sec  59}\n"
-	"    if {$hour > 23} {set hour 23}\n"
-	"    if {$mday < 1}  {set mday 1}\n"
-	"    if {$mday > 35} {set mday 35}\n"
-	"    if {$mon  < 1}  {set mon  1}\n"
-	"    if {$mon > 12}  {set mon  12}\n"
-	"\n"
-	"    set res 0\n"
-	"    while {$mday > 1 && [catch {\n"
-	"	set dt [format {%4.4d-%2.2d-%2.2d %2.2d:%2.2d:%2.2d} \\\n"
-	"		    $year $mon $mday $hour $min $sec]\n"
-	"	set res [clock scan $dt -gmt 1]\n"
-	"    }]} {\n"
-	"	# Only mday can be wrong, at end of month\n"
-	"	incr mday -1\n"
-	"    }\n"
-	"\n"
-	"    return $res\n"
 	"}\n"
 	"\n"
 	"\n"
