@@ -16,7 +16,8 @@ SRCURL="http://prdownloads.sourceforge.net/tcl/tcl${TCLVERS}-src.tar.gz"
 BUILDDIR="$(pwd)/build/tcl${TCLVERS}"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
-export SRC SRCURL BUILDDIR OUTDIR INSTDIR
+PATCHSCRIPTDIR="$(pwd)/patchscripts"
+export SRC SRCURL BUILDDIR OUTDIR INSTDIR PATCHSCRIPTDIR
 
 rm -rf 'build' 'out' 'inst'
 mkdir 'build' 'out' 'inst' || exit 1
@@ -54,20 +55,39 @@ fi
 	fi
 
 	cd "${BUILDDIR}" || exit 1
-	for dir in unix win macosx; do
+
+	# Apply patch scripts if needed
+	for patchscript in "${PATCHSCRIPTDIR}"/*.sh; do
+		if [ -f "${patchscript}" ]; then
+			echo "Running patch script: ${patchscript}"
+			. "${patchscript}"
+		fi
+	done
+
+	for dir in unix win macosx __fail__; do
+		if [ "${dir}" = "__fail__" ]; then
+			# If we haven't figured out how to build it, reject.
+
+			exit 1
+		fi
+
 		# Remove previous directory's "tclConfig.sh" if found
 		rm -f 'tclConfig.sh'
 
 		cd "${BUILDDIR}/${dir}" || exit 1
 
+		echo "Running: ./configure --disable-shared --with-encoding=utf-8 --prefix=\"${INSTDIR}\" ${CONFIGUREEXTRA}"
 		./configure --disable-shared --with-encoding=utf-8 --prefix="${INSTDIR}" ${CONFIGUREEXTRA}
 
+		echo "Running: ${MAKE:-make}"
 		${MAKE:-make} || continue
 
+		echo "Running: ${MAKE:-make} install"
 		${MAKE:-make} install || (
 			# Work with Tcl 8.6.x's TCLSH_NATIVE solution for
 			# cross-compile installs
 
+			echo "Running: ${MAKE:-make} install TCLSH_NATIVE=\"${TCLKIT:-tclkit}\""
 			${MAKE:-make} install TCLSH_NATIVE="${TCLKIT:-tclkit}"
 		) || (
 			# Make install can fail if cross-compiling using Tcl 8.5.x
@@ -77,7 +97,18 @@ fi
 			cat Makefile.new > Makefile
 			rm -f Makefile.new
 
+			echo "Running: ${MAKE:-make} install TCLSH=\"../../../../../../../../../../../../../../../../../$(which "${TCLKIT:-tclkit}")\""
 			${MAKE:-make} install TCLSH="../../../../../../../../../../../../../../../../../$(which "${TCLKIT:-tclkit}")"
+		) || (
+			# Make install can fail if cross-compiling using Tcl 8.5.9
+			# because the Makefile calls "${TCL_EXE}".  We can't simply
+			# redefine TCL_EXE because it also uses TCL_EXE as a build target
+			sed 's@^${TCL_EXE}@blah@' Makefile > Makefile.new
+			cat Makefile.new > Makefile
+			rm -f Makefile.new
+
+			echo "Running: ${MAKE:-make} install TCL_EXE=\"../../../../../../../../../../../../../../../../../$(which "${TCLKIT:-tclkit}")\""
+			${MAKE:-make} install TCL_EXE="../../../../../../../../../../../../../../../../../$(which "${TCLKIT:-tclkit}")"
 		) || exit 1
 
 		mkdir "${OUTDIR}/lib" || exit 1
