@@ -72,8 +72,13 @@ fi
 	fi
 
 	# Build static version
+	echo "Running: ./configure --disable-shared --prefix=\"${INSTDIR}\" --exec-prefix=\"${INSTDIR}\" --with-tcl=\"${TCLCONFIGDIR}\" ${CONFIGUREEXTRA}"
 	./configure --disable-shared --prefix="${INSTDIR}" --exec-prefix="${INSTDIR}" --with-tcl="${TCLCONFIGDIR}" ${CONFIGUREEXTRA}
+
+	echo "Running: ${MAKE:-make}"
 	${MAKE:-make} || exit 1
+
+	echo "Running: ${MAKE:-make} install"
 	${MAKE:-make} install
 
 	mkdir "${OUTDIR}/lib" || exit 1
