@@ -46,10 +46,13 @@ fi
 
 	# We don't pass CONFIGUREEXTRA here, since this isn't a GNU autoconf
 	# script and will puke
+	echo "Running: ./configure --prefix=\"${INSTDIR}\""
 	./configure --prefix="${INSTDIR}"
 
+	echo "Running: ${MAKE:-make} AR=\"${AR}\""
 	${MAKE:-make} AR="${AR}" || exit 1
 
+	echo "Running: ${MAKE:-make} install AR=\"${AR}\""
 	${MAKE:-make} install AR="${AR}"
 
 	# We don't really care too much about failure in zlib
